@@ -190,6 +190,7 @@ class Compiler(object):
 
     def interpolate(self,text):
         return self._interpolate(text,lambda x:'{{%s}}'%x)
+ 
     def visitText(self,text):
         text = ''.join(text.nodes)
         text = self.interpolate(text)
@@ -244,10 +245,10 @@ class Compiler(object):
             self.visit(code.block)
             # if not code.buffer: self.buf.append('}')
 
-        if not code.buffer:
-          codeTag = code.val.strip().split(' ',1)[0]
-          if codeTag in self.autocloseCode:
-              self.buf.append('{%% end%s %%}'%codeTag)
+            if not code.buffer:
+              codeTag = code.val.strip().split(' ',1)[0]
+              if codeTag in self.autocloseCode:
+                  self.buf.append('{%% end%s %%}'%codeTag)
 
     def visitEach(self,each):
         self.buf.append('{%% for %s in %s %%}'%(','.join(each.keys),each.obj))
@@ -288,4 +289,16 @@ class Compiler(object):
             else:
                 temp_attrs.append(attr)
         
-        if temp_attrs: self.visitDynamicAttributes(temp_attrs)
\ No newline at end of file
+        if temp_attrs: self.visitDynamicAttributes(temp_attrs)
+
+try:
+    import coffeescript
+    Compiler.filters['coffeescript'] = lambda x, y: '<script>%s</script>' % coffeescript.compile(x)
+except ImportError:
+    pass
+
+try:
+    import markdown
+    Compiler.filters['markdown'] = lambda x,y: markdown.markdown(x, output_format='html5')
+except ImportError:
+    pass
\ No newline at end of file
